@@ -1,7 +1,7 @@
 package Parse::PayPal::TxDetailReport;
 
 our $DATE = '2016-07-21'; # DATE
-our $VERSION = '0.004'; # VERSION
+our $VERSION = '0.005'; # VERSION
 
 use 5.010001;
 use strict;
@@ -102,7 +102,9 @@ sub parse_paypal_txdetail_report {
         return [400, "Please specify files (or strings)"];
     }
 
-    my $res = [200, "OK", {}];
+    my $res = [200, "OK", {
+        transactions => [],
+    }];
 
     my $code_parse_row = sub {
         my $row = shift;
@@ -235,7 +237,7 @@ Parse::PayPal::TxDetailReport - Parse PayPal transaction detail report into data
 
 =head1 VERSION
 
-This document describes version 0.004 of Parse::PayPal::TxDetailReport (from Perl distribution Parse-PayPal-TxDetailReport), released on 2016-07-21.
+This document describes version 0.005 of Parse::PayPal::TxDetailReport (from Perl distribution Parse-PayPal-TxDetailReport), released on 2016-07-21.
 
 =head1 SYNOPSIS
 
